@@ -6,7 +6,7 @@ use Duadua::Util qw//;
 sub try {
     my ($class, $d) = @_;
 
-    if ( $d->contain('similartech.com') ) {
+    if ( $d->_contain('similartech.com') ) {
         my $h = {
             name   => 'SMTBot',
             is_bot => 1,
