@@ -6,10 +6,10 @@ use Duadua::Util qw//;
 sub try {
     my ($class, $d) = @_;
 
-    return if $d->contain('http');
-    return if $d->contain(' BingPreview');
+    return if $d->_contain('http');
+    return if $d->_contain(' BingPreview');
 
-    if ( $d->contain('MSIE ') && $d->contain_mozilla && $d->contain('Windows ') ) {
+    if ( $d->_contain('MSIE ') && $d->_contain_mozilla && $d->_contain('Windows ') ) {
         my $h = {
             name       => 'Internet Explorer',
             is_windows => 1,
@@ -23,7 +23,7 @@ sub try {
         return $h;
     }
 
-    if ( $d->contain('Trident/') && $d->contain(' rv:1') && $d->contain_mozilla && $d->contain('Windows ') ) {
+    if ( $d->_contain('Trident/') && $d->_contain(' rv:1') && $d->_contain_mozilla && $d->_contain('Windows ') ) {
         my $h = {
             name       => 'Internet Explorer',
             is_windows => 1,
@@ -37,7 +37,7 @@ sub try {
         return $h;
     }
 
-    if ( $d->contain('Windows-RSS-Platform/') ) {
+    if ( $d->_contain('Windows-RSS-Platform/') ) {
         my $h = {
             name => 'Windows RSS Platform',
         };
